1 earth_radius
earth_radius
1.1 Functions
| Name | Description |
|---|---|
| earth_radius | Compute the earth radius giving the geocentric or geodetic latitude |
| geocentric_to_geodetic_lat | Convert geocentric latitude to geodetic latitude |
| geodetic_to_geocentric_lat | Convert geodetic latitude to geocentric latitude |
1.1.1 earth_radius
earth_radius.earth_radius(lat, lat_type='geocentric')Compute the earth radius giving the geocentric or geodetic latitude
1.1.1.1 Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| lat | (float,) | Geocentric or geodetic latitude in degrees | required |
| lat_type | str | The latitude type, 2 options: “geocentric”, “geodetic” | 'geocentric' |
1.1.1.2 Returns
| Name | Type | Description |
|---|---|---|
| rad | float | The earth radius at the given latitude |
1.1.2 geocentric_to_geodetic_lat
earth_radius.geocentric_to_geodetic_lat(lat)Convert geocentric latitude to geodetic latitude
1.1.2.1 Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| lat | float | Geocentric latitude in degrees | required |
1.1.2.2 Returns
| Name | Type | Description |
|---|---|---|
| out | float | Geodetic latitude in degrees |
1.1.3 geodetic_to_geocentric_lat
earth_radius.geodetic_to_geocentric_lat(lat)Convert geodetic latitude to geocentric latitude
1.1.3.1 Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| lat | float | Geodetic latitude in degrees | required |
1.1.3.2 Returns
| Name | Type | Description |
|---|---|---|
| out | float | Geocentric latitude in degrees |