1 glint
glint
1.1 Functions
| Name | Description |
|---|---|
| glitter | This function computes glitter’s normalized radiance from |
1.1.1 glitter
glint.glitter(wind, mu_s, mu_v, gamma, phi=None, phi_vent=None)This function computes glitter’s normalized radiance from Cox and Munk wave slope probability density function model, for isotropic or directionnal approximation
Arguments: float wind [IN] : Norm of the wind surface vector [m/s] float mu_s [IN] : Cosine of the solar zenith angle float mu_v [IN] : Cosine of the viewing zenith angle float gamma [IN] : Scattering angle (degrees) Directional approximation: (not used if phi and phi_vent are None (default)) float phi [IN] : Relative azimutal angle between solar azimtual angle and viewing azimutal angle (degrees) float phi_vent [IN] : Relative azimutal angle between solar azimutal angle and wind azimutal angle (degrees)